Crate odpic_sys

odpic-sys

The crate provides low-level Rust bindings to ODPI-C.

Usage

Put this in your Cargo.toml:

[dependencies]
odpic-sys = "0.1.0"

The following Cargo features are supported:

  • separate_blocking separates functions which may be blocked by network round-trips.

    When the feature is enabled, functions whose column Round-Trips? value in ODPI-C Function Round-Trips is Yes or Maybe are moved from the top-level module to the blocking module.

Compile-time Requirements

See Compile-time Requirements.

Relation between odpic-sys version and ODPI-C version

odpic-sys versionODPI-C versionRustTarget
0.1.15.4.11.59
0.1.05.4.01.59

License

Same with ODPI-C

  1. the Universal Permissive License v 1.0 or at your option, any later version; and/or
  2. the Apache License v 2.0.

Modules

blocking
functions which may be blocked by network-roundtrips
dpi_impl
This module provides constants in dpiImpl.h.

Structs

dpiAccessToken
dpiAnnotation
dpiAppContext
dpiBytes
dpiCommonCreateParams
dpiConn
dpiConnCreateParams
dpiConnInfo
dpiContext
dpiContextCreateParams
dpiData
dpiDataTypeInfo
dpiDeqOptions
dpiEncodingInfo
dpiEnqOptions
dpiErrorInfo
dpiIntervalDS
dpiIntervalYM
dpiJson
dpiJsonArray
dpiJsonNode
dpiJsonObject
dpiLob
dpiMsgProps
dpiMsgRecipient
dpiObject
dpiObjectAttr
dpiObjectAttrInfo
dpiObjectType
dpiObjectTypeInfo
dpiPool
dpiPoolCreateParams
dpiQueryInfo
dpiQueue
dpiRowid
dpiShardingKeyColumn
dpiSodaColl
dpiSodaCollCursor
dpiSodaDb
dpiSodaDoc
dpiSodaDocCursor
dpiSodaOperOptions
dpiStmt
dpiStmtInfo
dpiStringList
dpiSubscr
dpiSubscrCreateParams
dpiSubscrMessage
dpiSubscrMessageQuery
dpiSubscrMessageRow
dpiSubscrMessageTable
dpiTimestamp
dpiVar
dpiVector
dpiVectorInfo
dpiVersionInfo
dpiXid

Constants

DPI_DEBUG_LEVEL_ERRORS
DPI_DEBUG_LEVEL_FNS
DPI_DEBUG_LEVEL_LOAD_LIB
DPI_DEBUG_LEVEL_MEM
DPI_DEBUG_LEVEL_REFS
DPI_DEBUG_LEVEL_SQL
DPI_DEBUG_LEVEL_UNREPORTED_ERRORS
DPI_DEFAULT_FETCH_ARRAY_SIZE
DPI_DEFAULT_PING_INTERVAL
DPI_DEFAULT_PING_TIMEOUT
DPI_DEFAULT_PREFETCH_ROWS
DPI_DEFAULT_STMT_CACHE_SIZE
DPI_DEQ_NAV_FIRST_MSG
DPI_DEQ_NAV_NEXT_MSG
DPI_DEQ_NAV_NEXT_TRANSACTION
DPI_DEQ_WAIT_NO_WAIT
DPI_EVENT_AQ
DPI_EVENT_DEREG
DPI_EVENT_NONE
DPI_EVENT_OBJCHANGE
DPI_EVENT_QUERYCHANGE
DPI_EVENT_SHUTDOWN
DPI_EVENT_SHUTDOWN_ANY
DPI_EVENT_STARTUP
DPI_FAILURE
DPI_JSON_OPT_DATE_AS_DOUBLE
DPI_JSON_OPT_DEFAULT
DPI_JSON_OPT_NUMBER_AS_STRING
DPI_MAJOR_VERSION
DPI_MAX_INT64_PRECISION
DPI_MINOR_VERSION
DPI_MODE_AUTH_DEFAULT
DPI_MODE_AUTH_PRELIM
DPI_MODE_AUTH_SYSASM
DPI_MODE_AUTH_SYSBKP
DPI_MODE_AUTH_SYSDBA
DPI_MODE_AUTH_SYSDGD
DPI_MODE_AUTH_SYSKMT
DPI_MODE_AUTH_SYSOPER
DPI_MODE_AUTH_SYSRAC
DPI_MODE_CONN_CLOSE_DEFAULT
DPI_MODE_CONN_CLOSE_DROP
DPI_MODE_CONN_CLOSE_RETAG
DPI_MODE_CREATE_DEFAULT
DPI_MODE_CREATE_EVENTS
DPI_MODE_CREATE_THREADED
DPI_MODE_DEQ_BROWSE
DPI_MODE_DEQ_LOCKED
DPI_MODE_DEQ_REMOVE
DPI_MODE_DEQ_REMOVE_NO_DATA
DPI_MODE_EXEC_ARRAY_DML_ROWCOUNTS
DPI_MODE_EXEC_BATCH_ERRORS
DPI_MODE_EXEC_COMMIT_ON_SUCCESS
DPI_MODE_EXEC_DEFAULT
DPI_MODE_EXEC_DESCRIBE_ONLY
DPI_MODE_EXEC_PARSE_ONLY
DPI_MODE_FETCH_ABSOLUTE
DPI_MODE_FETCH_FIRST
DPI_MODE_FETCH_LAST
DPI_MODE_FETCH_NEXT
DPI_MODE_FETCH_PRIOR
DPI_MODE_FETCH_RELATIVE
DPI_MODE_MSG_BUFFERED
DPI_MODE_MSG_PERSISTENT
DPI_MODE_MSG_PERSISTENT_OR_BUFFERED
DPI_MODE_POOL_CLOSE_DEFAULT
DPI_MODE_POOL_CLOSE_FORCE
DPI_MODE_POOL_GET_FORCEGET
DPI_MODE_POOL_GET_NOWAIT
DPI_MODE_POOL_GET_TIMEDWAIT
DPI_MODE_POOL_GET_WAIT
DPI_MODE_SHUTDOWN_ABORT
DPI_MODE_SHUTDOWN_DEFAULT
DPI_MODE_SHUTDOWN_FINAL
DPI_MODE_SHUTDOWN_IMMEDIATE
DPI_MODE_SHUTDOWN_TRANSACTIONAL
DPI_MODE_SHUTDOWN_TRANSACTIONAL_LOCAL
DPI_MODE_STARTUP_DEFAULT
DPI_MODE_STARTUP_FORCE
DPI_MODE_STARTUP_RESTRICT
DPI_MSG_STATE_EXPIRED
DPI_MSG_STATE_PROCESSED
DPI_MSG_STATE_READY
DPI_MSG_STATE_WAITING
DPI_NATIVE_TYPE_BOOLEAN
DPI_NATIVE_TYPE_BYTES
DPI_NATIVE_TYPE_DOUBLE
DPI_NATIVE_TYPE_FLOAT
DPI_NATIVE_TYPE_INT64
DPI_NATIVE_TYPE_INTERVAL_DS
DPI_NATIVE_TYPE_INTERVAL_YM
DPI_NATIVE_TYPE_JSON
DPI_NATIVE_TYPE_JSON_ARRAY
DPI_NATIVE_TYPE_JSON_OBJECT
DPI_NATIVE_TYPE_LOB
DPI_NATIVE_TYPE_NULL
DPI_NATIVE_TYPE_OBJECT
DPI_NATIVE_TYPE_ROWID
DPI_NATIVE_TYPE_STMT
DPI_NATIVE_TYPE_TIMESTAMP
DPI_NATIVE_TYPE_UINT64
DPI_NATIVE_TYPE_VECTOR
DPI_OPCODE_ALL_OPS
DPI_OPCODE_ALL_ROWS
DPI_OPCODE_ALTER
DPI_OPCODE_DELETE
DPI_OPCODE_DROP
DPI_OPCODE_INSERT
DPI_OPCODE_UNKNOWN
DPI_OPCODE_UPDATE
DPI_ORACLE_TYPE_BFILE
DPI_ORACLE_TYPE_BLOB
DPI_ORACLE_TYPE_BOOLEAN
DPI_ORACLE_TYPE_CHAR
DPI_ORACLE_TYPE_CLOB
DPI_ORACLE_TYPE_DATE
DPI_ORACLE_TYPE_INTERVAL_DS
DPI_ORACLE_TYPE_INTERVAL_YM
DPI_ORACLE_TYPE_JSON
DPI_ORACLE_TYPE_JSON_ARRAY
DPI_ORACLE_TYPE_JSON_ID
DPI_ORACLE_TYPE_JSON_OBJECT
DPI_ORACLE_TYPE_LONG_NVARCHAR
DPI_ORACLE_TYPE_LONG_RAW
DPI_ORACLE_TYPE_LONG_VARCHAR
DPI_ORACLE_TYPE_MAX
DPI_ORACLE_TYPE_NATIVE_DOUBLE
DPI_ORACLE_TYPE_NATIVE_FLOAT
DPI_ORACLE_TYPE_NATIVE_INT
DPI_ORACLE_TYPE_NATIVE_UINT
DPI_ORACLE_TYPE_NCHAR
DPI_ORACLE_TYPE_NCLOB
DPI_ORACLE_TYPE_NONE
DPI_ORACLE_TYPE_NUMBER
DPI_ORACLE_TYPE_NVARCHAR
DPI_ORACLE_TYPE_OBJECT
DPI_ORACLE_TYPE_RAW
DPI_ORACLE_TYPE_ROWID
DPI_ORACLE_TYPE_STMT
DPI_ORACLE_TYPE_TIMESTAMP
DPI_ORACLE_TYPE_TIMESTAMP_LTZ
DPI_ORACLE_TYPE_TIMESTAMP_TZ
DPI_ORACLE_TYPE_UROWID
DPI_ORACLE_TYPE_VARCHAR
DPI_ORACLE_TYPE_VECTOR
DPI_ORACLE_TYPE_XMLTYPE
DPI_PATCH_LEVEL
DPI_PURITY_DEFAULT
DPI_PURITY_NEW
DPI_PURITY_SELF
DPI_SERVER_TYPE_DEDICATED
DPI_SERVER_TYPE_POOLED
DPI_SERVER_TYPE_SHARED
DPI_SERVER_TYPE_UNKNOWN
DPI_SODA_FLAGS_ATOMIC_COMMIT
DPI_SODA_FLAGS_CREATE_COLL_MAP
DPI_SODA_FLAGS_DEFAULT
DPI_SODA_FLAGS_INDEX_DROP_FORCE
DPI_STMT_TYPE_ALTER
DPI_STMT_TYPE_BEGIN
DPI_STMT_TYPE_CALL
DPI_STMT_TYPE_COMMIT
DPI_STMT_TYPE_CREATE
DPI_STMT_TYPE_DECLARE
DPI_STMT_TYPE_DELETE
DPI_STMT_TYPE_DROP
DPI_STMT_TYPE_EXPLAIN_PLAN
DPI_STMT_TYPE_INSERT
DPI_STMT_TYPE_MERGE
DPI_STMT_TYPE_ROLLBACK
DPI_STMT_TYPE_SELECT
DPI_STMT_TYPE_UNKNOWN
DPI_STMT_TYPE_UPDATE
DPI_SUBSCR_GROUPING_CLASS_TIME
DPI_SUBSCR_GROUPING_TYPE_LAST
DPI_SUBSCR_GROUPING_TYPE_SUMMARY
DPI_SUBSCR_NAMESPACE_AQ
DPI_SUBSCR_NAMESPACE_DBCHANGE
DPI_SUBSCR_PROTO_CALLBACK
DPI_SUBSCR_PROTO_HTTP
DPI_SUBSCR_PROTO_MAIL
DPI_SUBSCR_PROTO_PLSQL
DPI_SUBSCR_QOS_BEST_EFFORT
DPI_SUBSCR_QOS_DEREG_NFY
DPI_SUBSCR_QOS_QUERY
DPI_SUBSCR_QOS_RELIABLE
DPI_SUBSCR_QOS_ROWIDS
DPI_SUCCESS
DPI_TPC_BEGIN_JOIN
DPI_TPC_BEGIN_NEW
DPI_TPC_BEGIN_PROMOTE
DPI_TPC_BEGIN_RESUME
DPI_TPC_END_NORMAL
DPI_TPC_END_SUSPEND
DPI_VECTOR_FLAGS_FLEXIBLE_DIM
DPI_VECTOR_FORMAT_BINARY
DPI_VECTOR_FORMAT_FLOAT32
DPI_VECTOR_FORMAT_FLOAT64
DPI_VECTOR_FORMAT_INT8
DPI_VISIBILITY_IMMEDIATE
DPI_VISIBILITY_ON_COMMIT

Functions

dpiConn_addRef
dpiConn_breakExecution
dpiConn_changePassword
dpiConn_close
dpiConn_commit
dpiConn_create
dpiConn_deqObject
dpiConn_enqObject
dpiConn_getCallTimeout
dpiConn_getCurrentSchema
dpiConn_getDbDomain
dpiConn_getDbName
dpiConn_getEdition
dpiConn_getEncodingInfo
dpiConn_getExternalName
dpiConn_getHandle
dpiConn_getInfo
dpiConn_getInstanceName
dpiConn_getInternalName
dpiConn_getIsHealthy
dpiConn_getLTXID
dpiConn_getMaxOpenCursors
dpiConn_getObjectType
dpiConn_getOciAttr
dpiConn_getServerVersion
dpiConn_getServiceName
dpiConn_getSodaDb
dpiConn_getStmtCacheSize
dpiConn_getTransactionInProgress
dpiConn_newDeqOptions
dpiConn_newEnqOptions
dpiConn_newJson
dpiConn_newJsonQueue
dpiConn_newMsgProps
dpiConn_newQueue
dpiConn_newTempLob
dpiConn_newVar
dpiConn_newVector
dpiConn_ping
dpiConn_prepareStmt
dpiConn_release
dpiConn_rollback
dpiConn_setAction
dpiConn_setCallTimeout
dpiConn_setClientIdentifier
dpiConn_setClientInfo
dpiConn_setCurrentSchema
dpiConn_setDbOp
dpiConn_setEcontextId
dpiConn_setExternalName
dpiConn_setInternalName
dpiConn_setModule
dpiConn_setOciAttr
dpiConn_setStmtCacheSize
dpiConn_shutdownDatabase
dpiConn_startupDatabase
dpiConn_startupDatabaseWithPfile
dpiConn_subscribe
dpiConn_tpcBegin
dpiConn_tpcCommit
dpiConn_tpcEnd
dpiConn_tpcForget
dpiConn_tpcPrepare
dpiConn_tpcRollback
dpiConn_unsubscribe
dpiContext_createWithParams
dpiContext_destroy
dpiContext_freeStringList
dpiContext_getClientVersion
dpiContext_getError
dpiContext_initCommonCreateParams
dpiContext_initConnCreateParams
dpiContext_initPoolCreateParams
dpiContext_initSodaOperOptions
dpiContext_initSubscrCreateParams
dpiData_getBool
dpiData_getBytes
dpiData_getDouble
dpiData_getFloat
dpiData_getInt64
dpiData_getIntervalDS
dpiData_getIntervalYM
dpiData_getIsNull
dpiData_getJson
dpiData_getJsonArray
dpiData_getJsonObject
dpiData_getLOB
dpiData_getObject
dpiData_getStmt
dpiData_getTimestamp
dpiData_getUint64
dpiData_setBool
dpiData_setBytes
dpiData_setDouble
dpiData_setFloat
dpiData_setInt64
dpiData_setIntervalDS
dpiData_setIntervalYM
dpiData_setLOB
dpiData_setNull
dpiData_setObject
dpiData_setStmt
dpiData_setTimestamp
dpiData_setUint64
dpiDeqOptions_addRef
dpiDeqOptions_getCondition
dpiDeqOptions_getConsumerName
dpiDeqOptions_getCorrelation
dpiDeqOptions_getMode
dpiDeqOptions_getMsgId
dpiDeqOptions_getNavigation
dpiDeqOptions_getTransformation
dpiDeqOptions_getVisibility
dpiDeqOptions_getWait
dpiDeqOptions_release
dpiDeqOptions_setCondition
dpiDeqOptions_setConsumerName
dpiDeqOptions_setCorrelation
dpiDeqOptions_setDeliveryMode
dpiDeqOptions_setMode
dpiDeqOptions_setMsgId
dpiDeqOptions_setNavigation
dpiDeqOptions_setTransformation
dpiDeqOptions_setVisibility
dpiDeqOptions_setWait
dpiEnqOptions_addRef
dpiEnqOptions_getTransformation
dpiEnqOptions_getVisibility
dpiEnqOptions_release
dpiEnqOptions_setDeliveryMode
dpiEnqOptions_setTransformation
dpiEnqOptions_setVisibility
dpiJson_addRef
dpiJson_getValue
dpiJson_release
dpiJson_setFromText
dpiJson_setValue
dpiLob_addRef
dpiLob_close
dpiLob_closeResource
dpiLob_copy
dpiLob_getBufferSize
dpiLob_getChunkSize
dpiLob_getDirectoryAndFileName
dpiLob_getFileExists
dpiLob_getIsResourceOpen
dpiLob_getSize
dpiLob_getType
dpiLob_openResource
dpiLob_readBytes
dpiLob_release
dpiLob_setDirectoryAndFileName
dpiLob_setFromBytes
dpiLob_trim
dpiLob_writeBytes
dpiMsgProps_addRef
dpiMsgProps_getCorrelation
dpiMsgProps_getDelay
dpiMsgProps_getDeliveryMode
dpiMsgProps_getEnqTime
dpiMsgProps_getExceptionQ
dpiMsgProps_getExpiration
dpiMsgProps_getMsgId
dpiMsgProps_getNumAttempts
dpiMsgProps_getOriginalMsgId
dpiMsgProps_getPayload
dpiMsgProps_getPayloadJson
dpiMsgProps_getPriority
dpiMsgProps_getState
dpiMsgProps_release
dpiMsgProps_setCorrelation
dpiMsgProps_setDelay
dpiMsgProps_setExceptionQ
dpiMsgProps_setExpiration
dpiMsgProps_setOriginalMsgId
dpiMsgProps_setPayloadBytes
dpiMsgProps_setPayloadJson
dpiMsgProps_setPayloadObject
dpiMsgProps_setPriority
dpiMsgProps_setRecipients
dpiObjectAttr_addRef
dpiObjectAttr_getInfo
dpiObjectAttr_release
dpiObjectType_addRef
dpiObjectType_createObject
dpiObjectType_getAttributes
dpiObjectType_getInfo
dpiObjectType_release
dpiObject_addRef
dpiObject_appendElement
dpiObject_copy
dpiObject_deleteElementByIndex
dpiObject_getAttributeValue
dpiObject_getElementExistsByIndex
dpiObject_getElementValueByIndex
dpiObject_getFirstIndex
dpiObject_getLastIndex
dpiObject_getNextIndex
dpiObject_getPrevIndex
dpiObject_getSize
dpiObject_release
dpiObject_setAttributeValue
dpiObject_setElementValueByIndex
dpiObject_trim
dpiPool_acquireConnection
dpiPool_addRef
dpiPool_close
dpiPool_create
dpiPool_getBusyCount
dpiPool_getEncodingInfo
dpiPool_getGetMode
dpiPool_getMaxLifetimeSession
dpiPool_getMaxSessionsPerShard
dpiPool_getOpenCount
dpiPool_getPingInterval
dpiPool_getSodaMetadataCache
dpiPool_getStmtCacheSize
dpiPool_getTimeout
dpiPool_getWaitTimeout
dpiPool_reconfigure
dpiPool_release
dpiPool_setAccessToken
dpiPool_setGetMode
dpiPool_setMaxLifetimeSession
dpiPool_setMaxSessionsPerShard
dpiPool_setPingInterval
dpiPool_setSodaMetadataCache
dpiPool_setStmtCacheSize
dpiPool_setTimeout
dpiPool_setWaitTimeout
dpiQueue_addRef
dpiQueue_deqMany
dpiQueue_deqOne
dpiQueue_enqMany
dpiQueue_enqOne
dpiQueue_getDeqOptions
dpiQueue_getEnqOptions
dpiQueue_release
dpiRowid_addRef
dpiRowid_getStringValue
dpiRowid_release
dpiSodaCollCursor_addRef
dpiSodaCollCursor_close
dpiSodaCollCursor_getNext
dpiSodaCollCursor_release
dpiSodaColl_addRef
dpiSodaColl_createIndex
dpiSodaColl_drop
dpiSodaColl_dropIndex
dpiSodaColl_find
dpiSodaColl_findOne
dpiSodaColl_getDataGuide
dpiSodaColl_getDocCount
dpiSodaColl_getMetadata
dpiSodaColl_getName
dpiSodaColl_insertMany
dpiSodaColl_insertManyWithOptions
dpiSodaColl_insertOne
dpiSodaColl_insertOneWithOptions
dpiSodaColl_listIndexes
dpiSodaColl_release
dpiSodaColl_remove
dpiSodaColl_replaceOne
dpiSodaColl_save
dpiSodaColl_saveWithOptions
dpiSodaColl_truncate
dpiSodaDb_addRef
dpiSodaDb_createCollection
dpiSodaDb_createDocument
dpiSodaDb_createJsonDocument
dpiSodaDb_freeCollectionNames
dpiSodaDb_getCollectionNames
dpiSodaDb_getCollections
dpiSodaDb_openCollection
dpiSodaDb_release
dpiSodaDocCursor_addRef
dpiSodaDocCursor_close
dpiSodaDocCursor_getNext
dpiSodaDocCursor_release
dpiSodaDoc_addRef
dpiSodaDoc_getContent
dpiSodaDoc_getCreatedOn
dpiSodaDoc_getIsJson
dpiSodaDoc_getJsonContent
dpiSodaDoc_getKey
dpiSodaDoc_getLastModified
dpiSodaDoc_getMediaType
dpiSodaDoc_getVersion
dpiSodaDoc_release
dpiStmt_addRef
dpiStmt_bindByName
dpiStmt_bindByPos
dpiStmt_bindValueByName
dpiStmt_bindValueByPos
dpiStmt_close
dpiStmt_define
dpiStmt_defineValue
dpiStmt_deleteFromCache
dpiStmt_execute
dpiStmt_executeMany
dpiStmt_fetch
dpiStmt_fetchRows
dpiStmt_getBatchErrorCount
dpiStmt_getBatchErrors
dpiStmt_getBindCount
dpiStmt_getBindNames
dpiStmt_getFetchArraySize
dpiStmt_getImplicitResult
dpiStmt_getInfo
dpiStmt_getLastRowid
dpiStmt_getNumQueryColumns
dpiStmt_getOciAttr
dpiStmt_getPrefetchRows
dpiStmt_getQueryInfo
dpiStmt_getQueryValue
dpiStmt_getRowCount
dpiStmt_getRowCounts
dpiStmt_getSubscrQueryId
dpiStmt_release
dpiStmt_scroll
dpiStmt_setFetchArraySize
dpiStmt_setOciAttr
dpiStmt_setPrefetchRows
dpiSubscr_addRef
dpiSubscr_prepareStmt
dpiSubscr_release
dpiVar_addRef
dpiVar_copyData
dpiVar_getNumElementsInArray
dpiVar_getReturnedData
dpiVar_getSizeInBytes
dpiVar_release
dpiVar_setFromBytes
dpiVar_setFromJson
dpiVar_setFromLob
dpiVar_setFromObject
dpiVar_setFromRowid
dpiVar_setFromStmt
dpiVar_setFromVector
dpiVar_setNumElementsInArray
dpiVector_addRef
dpiVector_getValue
dpiVector_release
dpiVector_setValue

Type Aliases

dpiAccessTokenCallback
dpiAuthMode
dpiConnCloseMode
dpiCreateMode
dpiDeqMode
dpiDeqNavigation
dpiEventType
dpiExecMode
dpiFetchMode
dpiMessageDeliveryMode
dpiMessageState
dpiNativeTypeNum
dpiOpCode
dpiOracleTypeNum
dpiPoolCloseMode
dpiPoolGetMode
dpiPurity
dpiServerType
dpiShutdownMode
dpiSodaCollNames
dpiStartupMode
dpiStatementType
dpiSubscrCallback
dpiSubscrGroupingClass
dpiSubscrGroupingType
dpiSubscrNamespace
dpiSubscrProtocol
dpiSubscrQOS
dpiTpcBeginFlags
dpiTpcEndFlags
dpiVectorFlags
dpiVectorFormat
dpiVisibility

Unions

dpiDataBuffer
dpiStringList__bindgen_ty_1
dpiStringList__bindgen_ty_2
dpiStringList__bindgen_ty_3
dpiVectorDimensionBuffer