Crate odpic_sys

odpic-sys

The crate provides low-level Rust bindings to ODPI-C.

Usage

Put this in your Cargo.toml:

[dependencies]
odpic-sys = "0.1.0"

The following Cargo features are supported:

  • separate_blocking separates functions which may be blocked by network round-trips.

    When the feature is enabled, functions whose column Round-Trips? value in ODPI-C Function Round-Trips is Yes or Maybe are moved from the top-level module to the blocking module.

Compile-time Requirements

See Compile-time Requirements.

Relation between odpic-sys version and ODPI-C version

odpic-sys versionODPI-C versionRustTarget
0.1.05.4.01.59

License

Same with ODPI-C

  1. the Universal Permissive License v 1.0 or at your option, any later version; and/or
  2. the Apache License v 2.0.

Modules

Structs

Constants

Functions

Type Aliases

Unions